var c = ICanvasRenderingContext2D(root.lookup("/device/canvas"));

c.fillStyle = "rgba(255, 255, 255, 1)";
c.fillRect(0, 0, 1024, 768);
